Button

Struct Button 

pub struct Button { /* private fields */ }

Implementations

Source

impl Button

pub fn new( bounds: Rect, title: &str, command: CommandId, is_default: bool, ) -> Self

pub fn set_disabled(&mut self, disabled: bool)

pub fn is_disabled(&self) -> bool

pub fn set_broadcast(&mut self, broadcast: bool)

Set whether this button broadcasts its command instead of sending it as a command event Matches Borland: bfBroadcast flag

pub fn set_selectable(&mut self, selectable: bool)

Set whether this button is selectable (can receive focus) Matches Borland: ofSelectable flag