pub struct Button { /* private fields */ }Implementations
Sourceimpl Button
impl Button
pub fn new( bounds: Rect, title: &str, command: CommandId, is_default: bool, ) -> Self
pub fn set_disabled(&mut self, disabled: bool)
pub fn is_disabled(&self) -> bool
Sourcepub fn set_broadcast(&mut self, broadcast: bool)
pub fn set_broadcast(&mut self, broadcast: bool)
Set whether this button broadcasts its command instead of sending it as a command event Matches Borland: bfBroadcast flag
Sourcepub fn set_selectable(&mut self, selectable: bool)
pub fn set_selectable(&mut self, selectable: bool)
Set whether this button is selectable (can receive focus) Matches Borland: ofSelectable flag